@@ -24,20 +24,13 @@ NULL
 #' own core and marginal area.}
 #' }
 #'
-#' The objects contained in this dataset are listed below.
-#'
-#' \describe{
-#' \item{sim_ru}{A \code{\link{RapUnsolved}} object with all the simulated
-#' data.}
-#' \item{sim_rs}{A \code{\link{RapSolved}} object with 5 near-optimal
-#' solutions.}
-#' }
-#'
 #' @docType data
 #'
-#' @format \code{\link[sp]{SpatialPolygonsDataFrame}},
-#'   \code{\link[raster]{RasterStack-class}}, \code{list} of
-#'   \code{\link{DemandPoints}} objects.
+#' @format
+#' \describe{
+#' \item{sim_ru}{[RapUnsolved()] object with all the simulated data.}
+#' \item{sim_rs}{[RapSolved()] object with 5 near-optimal solutions.}
+#' }
 #'
 #' @aliases sim_ru sim_rs
 #'
@@ -61,38 +54,32 @@ NULL
 #' plot(sim_rs, 0)
 NULL
 
-#' @rdname simulated_data
-"sim_ru"
-
-#' @rdname simulated_data
-"sim_rs"
-
 #' Case-study dataset for a conservation planning exercise
 #'
 #' This dataset contains data to generate example prioritizations for the
-#' pale-headed Rosella (\emph{Platycercus adscitus}) in Queensland, Australia.
+#' pale-headed Rosella (*Platycercus adscitus*) in Queensland, Australia.
 #'
 #' The objects in the dataset are listed below.
 #' \describe{
-#' \item{cs_pus}{\code{\link[sp]{SpatialPolygonsDataFrame}} planning units.
+#' \item{cs_pus}{[sp::SpatialPolygonsDataFrame()] planning units.
 #' The units were generated as \eqn{30km^2} squares across the
 #' species' range, and then clipped to the Queensland, Australia
-#' (using data obtained from the Australia Bureau of Statistics; \url{http://www.abs.gov.au/ausstats/abs@@.nsf/mf/1259.0.30.001?OpenDocument}).
+#' (using data obtained from the Australia Bureau of Statistics; <http://www.abs.gov.au/ausstats/abs@@.nsf/mf/1259.0.30.001?OpenDocument>).
 #' They were then overlaid with Australia's protected area
 #' network (obtained from the World Database on Protected Areas
-#' (WDPA) at \url{http://www.protectedplanet.net/}). This
-#' attribute table has 3 fields. The \code{area} field denotes
-#' the amount of land encompassed by each unit, the \code{cost}
-#' field is set to 1 for all units, and the \code{status} field
-#' indicates if 50\% or more of the units' extent is covered by
+#' (WDPA) at <http://www.protectedplanet.net/>). This
+#' attribute table has 3 fields. The `area` field denotes
+#' the amount of land encompassed by each unit, the `cost`
+#' field is set to 1 for all units, and the `status` field
+#' indicates if 50% or more of the units' extent is covered by
 #' protected areas.}
-#' \item{cs_spp}{\code{\link[raster]{RasterLayer-class}} probability
-#' distribution map for the \emph{P. adscitus} clipped to
+#' \item{cs_spp}{[raster::raster()] probability
+#' distribution map for the *P. adscitus* clipped to
 #' Queensland, Australia. This map was derived from records
-#' obtained from The Atlas of Living Australia (\url{http://ala.org.au/})}.
-#' \item{cs_space}{\code{\link[raster]{stack}} describing broad-scale climate
+#' obtained from The Atlas of Living Australia (<http://ala.org.au/>)}.
+#' \item{cs_space}{[raster::stack()] describing broad-scale climate
 #' variation across Queensland
-#' (obtained from \url{http://worldclim.org/},
+#' (obtained from <http://worldclim.org/>,
 #' and resampled to \eqn{10km^2} resolution).}
 #' }
 #'
@@ -100,7 +87,12 @@ NULL
 #'
 #' @aliases cs_pus cs_spp cs_space
 #'
-#' @format cs_pus: \code{\link[sp]{SpatialPolygonsDataFrame}}, cs_spp: \code{\link[raster]{RasterLayer-class}}, cs_space: \code{\link[raster]{RasterStack-class}}.
+#' @format
+#' \describe{
+#' \item{cs_pus}{[sp::SpatialPolygonsDataFrame()] object.}
+#' \item{cs_spp}{[raster::raster()] object.}
+#' \item{cs_space}{[raster::stack()] object.}
+#' }
 #'
 #' @keywords datasets
 #'
@@ -111,18 +103,9 @@ NULL
 #' data(cs_pus, cs_spp, cs_space)
 #'
 #' # plot data
-#' \donttest{
+#' \dontrun{
 #' plot(cs_pus)
 #' plot(cs_spp)
 #' plot(cs_space)
 #' }
 NULL
-
-#' @rdname casestudy_data
-"cs_pus"
-
-#' @rdname casestudy_data
-"cs_space"
-
-#' @rdname casestudy_data
-"cs_spp"
