@@ -4,16 +4,16 @@ NULL
 #' Test if Gurobi is installed
 #'
 #' This function determines if the Gurobi R package is installed on the
-#' computer and that it can be used \code{\link[base]{options}}.
+#' computer and that it can be used [base::options()].
 #'
-#' @param verbose \code{logical} should messages be printed?
+#' @param verbose `logical` should messages be printed?
 #'
-#' @return \code{logical} Is it installed and ready to use?
+#' @return `logical` Is it installed and ready to use?
 #'
-#' @seealso \code{\link[base]{options}}.
+#' @seealso [base::options()].
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' # check if Gurobi is installed
 #' is.GurobiInstalled()
 #'
@@ -68,91 +68,15 @@ is.GurobiInstalled <- function(verbose = TRUE) {
   return(TRUE)
 }
 
-#' Test if GDAL is installed on computer
-#'
-#' This function tests if GDAL is installed on the computer.
-#' If not, download it here: \url{http://download.osgeo.org/gdal}.
-#'
-#' @return \code{logical} is GDAL installed?
-#'
-#' @seealso \code{\link[gdalUtils]{gdal_setInstallation}}.
-#'
-#' @examples
-#' # check if gdal is installed on system
-#' \donttest{
-#' is.gdalInstalled()
-#' }
-#'
-#' @export
-is.gdalInstalled <- function() {
-  suppressWarnings(findGdalInstallationPaths())
-  return(!is.null(getOption("gdalUtils_gdalPath")))
-}
-
-#' Rasterize polygon data using GDAL
-#'
-#' This function converts a \code{SpatialPolygonsDataFrame} to a
-#' \code{RasterLayer} using GDAL. It is expected to be faster than
-#' \code{\link[raster]{rasterize}} for large datasets. However, it will be
-#' significantly slower for small datasets because the data will need to be
-#' written and read from disk.
-#'
-#' @param x \code{\link[sp]{SpatialPolygonsDataFrame}} object.
-#'
-#' @param y \code{\link[raster]{raster}} with dimensions, extent, and
-#'   resolution to be used as a template for new raster.
-#'
-#' @param field \code{character} column name with values to burn into the
-#'   output raster. If not supplied, default behaviour is to burn polygon
-#'   indices into the \code{\link[raster]{raster}}.
-#'
-#' @return \code{RasterLayer} object.
-#'
-#' @seealso \code{\link[raster]{rasterize}}, \code{\link{is.gdalInstalled}}.
-#'
-#' @examples
-#' \donttest{
-#' # load dat
-#' data(cs_pus,cs_spp)
-#'
-#' # rasterize spatial polygon data
-#' x <- rasterizeGDAL(cs_pus[1:5,], cs_spp[[1]])
-#'
-#' # plot data
-#' par(mfrow = c(1,2))
-#' plot(cs_pus[1:5,], main = "original data")
-#' plot(x, main = "rasterized data")
-#' }
-#'
-#' @export
-rasterizeGDAL <- function(x, y, field = NULL) {
-  assertthat::assert_that(inherits(x, "SpatialPolygonsDataFrame"),
-                          inherits(y, "RasterLayer"),
-                          is.null(field) || (assertthat::is.string(field) &&
-                                             field %in% names(x@data)))
-  if (is.null(field)) {
-    x@data$id <- seq_len(nrow(x@data))
-    field <- "id"
-  }
-  rgdal::writeOGR(x, tempdir(), "polys", driver = "ESRI Shapefile",
-                  overwrite_layer = TRUE)
-  raster::writeRaster(raster::setValues(y, NA), file.path(tempdir(),
-                      "rast.tif"), NAflag = -9999, overwrite = TRUE)
-  return(gdalUtils::gdal_rasterize(file.path(tempdir(), "polys.shp"),
-                                  file.path(tempdir(), "rast.tif"),
-                                  l = "polys", a = field,
-                                  output_Raster = TRUE)[[1]])
-}
-
 #' Blank raster
 #'
 #' This functions creates a blank raster based on the spatial extent of a
 #' Spatial object.
 #'
-#' @param x \code{\link[sp]{Spatial-class}} object.
+#' @param x [sp::Spatial-class] object.
 #'
-#' @param res \code{numeric vector} specifying resolution of the output raster
-#'   in the x and y dimensions. If \code{vector} is of length one, then the
+#' @param res `numeric` `vector` specifying resolution of the output raster
+#'   in the x and y dimensions. If `vector` is of length one, then the
 #'   pixels are assumed to be square.
 #'
 #' @examples
@@ -199,7 +123,7 @@ blank.raster <- function(x, res) {
 #'
 #' Object contains PolySet data.
 #'
-#' @seealso \code{\link[PBSmapping]{PolySet}}.
+#' @seealso [PBSmapping::PolySet()].
 #'
 #' @name PolySet-class
 #'
@@ -210,8 +134,8 @@ methods::setClass("PolySet")
 
 #' RapOpts class
 #'
-#' Object is either \code{\link{RapReliableOpts}} or
-#' \code{\link{RapUnreliableOpts}}.
+#' Object is either [RapReliableOpts()] or
+#' [RapUnreliableOpts()].
 #'
 #' @name RapOpts-class
 #'
@@ -228,7 +152,7 @@ methods::setClass("RapOpts",
 #'
 #' @name SolverOpts-class
 #'
-#' @seealso \code{\link{GurobiOpts}}.
+#' @seealso [GurobiOpts()].
 #'
 #' @aliases SolverOpts
 #'
@@ -237,20 +161,20 @@ methods::setClass("SolverOpts")
 
 #' Sample random points from a RasterLayer
 #'
-#' This function generates random points in a \code{\link[raster]{raster}}
+#' This function generates random points in a [raster::raster()]
 #' object.
 #'
-#' @param mask \code{\link[raster]{raster}} object
+#' @param mask [raster::raster()] object
 #'
-#' @param n \code{integer} number of points to sample
+#' @param n `integer` number of points to sample
 #'
-#' @param prob \code{logical} should the raster values be used as weights?
-#'   Defaults to \code{FALSE}.
+#' @param prob `logical` should the raster values be used as weights?
+#'   Defaults to `FALSE`.
 #'
-#' @return \code{\link[base]{matrix}} with x-coordinates, y-coordinates, and
+#' @return [base::matrix()] with x-coordinates, y-coordinates, and
 #'   cell values.
 #'
-#' @seealso This function is similar to \code{dismo::randomPoints}.
+#' @seealso This function is similar to `dismo::randomPoints`.
 #'
 #' @examples
 #' # simulate data
